/* libleptonrenderer - Rendering Lepton EDA schematics with Cairo
 * Copyright (C) 2010-2012 gEDA Contributors
 * Copyright (C) 2017-2020 Lepton EDA Contributors
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef __LIBLEPTONRENDERER_H__
#define __LIBLEPTONRENDERER_H__

#include <cairo.h>
#include <pango/pangocairo.h>

#include <libleptonrenderer/edarenderer.h>
#include <libleptonrenderer/edacairo.h>

#endif /* !__LIBLEPTONRENDERER_H__ */
